tuplettools.make_tuplet_from_duration_and_proportions
=====================================================

.. autofunction:: abjad.tools.tuplettools.make_tuplet_from_duration_and_proportions.make_tuplet_from_duration_and_proportions
